@@ -1,5 +1,6 @@
+from indic_transliteration import sanscript
 from sanskrit_parser.base.maheshvara_sutra import MaheshvaraSutras
-from sanskrit_parser.base.sanskrit_base import SanskritImmutableString, SLP1
+from sanskrit_parser.base.sanskrit_base import SanskritImmutableString
 
 ms = MaheshvaraSutras()
 
@@ -10,9 +11,9 @@ def isInPratyahara(p, s):
     if s == "":
         return False
     if isinstance(p, str):
-        p = SanskritImmutableString(p, SLP1)
+        p = SanskritImmutableString(p, sanscript.SLP1)
     if isinstance(s, str):
-        s = SanskritImmutableString(s, SLP1)
+        s = SanskritImmutableString(s, sanscript.SLP1)
     return ms.isInPratyahara(p, s)
 
 
@@ -24,9 +25,9 @@ def isSavarna(p, s):
         return True
     else:
         if isinstance(p, str):
-            p = SanskritImmutableString(p, SLP1)
+            p = SanskritImmutableString(p, sanscript.SLP1)
         if isinstance(s, str):
-            s = SanskritImmutableString(s, SLP1)
+            s = SanskritImmutableString(s, sanscript.SLP1)
         return ms.isSavarna(p, s)
 
 
