@@ -5,8 +5,8 @@ from flask import request
 # import subprocess
 # from os import path
 # from flask import redirect
-
-from sanskrit_parser.base.sanskrit_base import SanskritObject, SLP1
+from indic_transliteration import sanscript
+from sanskrit_parser.base.sanskrit_base import SanskritObject
 from sanskrit_parser.parser.sandhi_analyzer import LexicalSandhiAnalyzer
 from sanskrit_parser import __version__
 from sanskrit_parser import Parser
@@ -29,7 +29,7 @@ analyzer = LexicalSandhiAnalyzer()
 def jedge(pred, node, label):
     return (node.pada.devanagari(strict_io=False),
             jtag(node.getMorphologicalTags()),
-            SanskritObject(label, encoding=SLP1).devanagari(strict_io=False),
+            SanskritObject(label, encoding=sanscript.SLP1).devanagari(strict_io=False),
             pred.pada.devanagari(strict_io=False))
 
 
@@ -82,7 +82,10 @@ class Splits(Resource):
         g = analyzer.getSandhiSplits(vobj)
         if g:
             splits = g.find_all_paths(10)
-            jsplits = [[ss.devanagari(strict_io=False) for ss in s] for s in splits]
+            # We don't get output with visargas here.
+            # Why? Because this will need to be parsed later, and we need to distinguish s/r
+            # We rely on the UI to handle display correctly
+            jsplits = [[ss.devanagari(strict_io=True) for ss in s] for s in splits]
         else:
             jsplits = []
         r = {"input": v, "devanagari": vobj.devanagari(), "splits": jsplits}
@@ -97,11 +100,14 @@ class Parse_Presegmented(Resource):
         if request.args.get("strict") == "false":
             strict_p = False
         vobj = SanskritObject(v, strict_io=strict_p, replace_ending_visarga=None)
-        parser = Parser(input_encoding="SLP1",
-                        output_encoding="Devanagari",
+        # We set strict_io to False so we get output with visargas
+        # If further processing is desired, this needs to be set to True
+        # And the UI must handle display
+        parser = Parser(input_encoding=sanscript.SLP1,
+                        output_encoding=sanscript.DEVANAGARI,
+                        strict_io=False,   
                         replace_ending_visarga='s')
         mres = []
-        print(v)
         for split in parser.split(vobj.canonical(), limit=10, pre_segmented=True):
             parses = list(split.parse(limit=10))
             sdot = split.to_dot()
@@ -118,8 +124,8 @@ class Presegmented(Resource):
     def get(self, v):
         """ Presegmented Split """
         vobj = SanskritObject(v, strict_io=True, replace_ending_visarga=None)
-        parser = Parser(input_encoding="SLP1",
-                        output_encoding="Devanagari",
+        parser = Parser(input_encoding=sanscript.SLP1,
+                        output_encoding=sanscript.DEVANAGARI,
                         replace_ending_visarga='s')
         splits = parser.split(vobj.canonical(), limit=10, pre_segmented=True)
         r = {"input": v, "devanagari": vobj.devanagari(), "splits": [x.serializable()['split'] for x in splits]}
